import { Component, Input, forwardRef, ViewChild, ChangeDetectorRef } from '@angular/core';
import { AutoCompleteDirective } from './auto-complete.directive';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { RebirthNGConfig } from '../rebirth-ng.config';
var MutipleAutoCompleteComponent = (function () {
    function MutipleAutoCompleteComponent(rebirthNGConfig, changeDetectorRef) {
        this.rebirthNGConfig = rebirthNGConfig;
        this.changeDetectorRef = changeDetectorRef;
        this.appendBody = false;
        this.onChange = function (_) { return null; };
        this.onTouched = function () { return null; };
        this.delay = rebirthNGConfig.autoComplete.delay;
        this.minLength = rebirthNGConfig.autoComplete.minLength;
        this.itemTemplate = rebirthNGConfig.autoComplete.itemTemplate;
        this.noResultItemTemplate = rebirthNGConfig.autoComplete.noResultItemTemplate;
        this.formatter = rebirthNGConfig.autoComplete.formatter;
        this.valueParser = rebirthNGConfig.autoComplete.valueParser;
        this.id = MutipleAutoCompleteComponent.ID_SEED++;
    }
    MutipleAutoCompleteComponent.prototype.writeValue = function (obj) {
        this.mutipleItems = obj || [];
        this.changeDetectorRef.markForCheck();
    };
    MutipleAutoCompleteComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    MutipleAutoCompleteComponent.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    MutipleAutoCompleteComponent.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
    };
    MutipleAutoCompleteComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (this.autoCompleteDirective) {
            this.autoCompleteDirective.registerOnTouched(function () { return _this.onTouched(); });
        }
    };
    MutipleAutoCompleteComponent.prototype.toggle = function ($event) {
        if (this.autoCompleteDirective) {
            this.autoCompleteDirective.toggle($event);
        }
    };
    MutipleAutoCompleteComponent.prototype.onMutipleSearch = function () {
        this.onTouched();
        if (this.mutipleItems.indexOf(this.selectValue) === -1) {
            this.mutipleItems.push(this.selectValue);
            this.onChange(this.mutipleItems);
        }
        this.selectValue = null;
    };
    MutipleAutoCompleteComponent.prototype.removeLabel = function (label) {
        if (this.disabled) {
            return;
        }
        this.onTouched();
        if (this.mutipleItems.indexOf(label) !== -1) {
            this.mutipleItems = this.mutipleItems.filter(function (item) { return item !== label; });
            this.onChange(this.mutipleItems);
        }
    };
    MutipleAutoCompleteComponent.prototype.onMutipleSearchBoxBackspace = function ($event) {
        var _this = this;
        this.onTouched();
        if (!$event.target.value && this.mutipleItems.length) {
            this.mutipleItems.pop();
            this.onChange(this.mutipleItems);
            setTimeout(function () { return _this.autoCompleteDirective.positionPopup(); }, 0);
        }
    };
    return MutipleAutoCompleteComponent;
}());
export { MutipleAutoCompleteComponent };
MutipleAutoCompleteComponent.ID_SEED = 0;
MutipleAutoCompleteComponent.decorators = [
    { type: Component, args: [{
                selector: 're-mutiple-auto-complete',
                template: "\n    <label for=\"mutiple-label-auto-complete-{{id}}\" class=\"mutiple-label-auto-complete {{cssClass}}\"><ul><li *ngFor=\"let item of mutipleItems\"><span class=\"label label-info\" [ngClass]=\"{disabled: disabled}\"><i aria-hidden=\"true\" class=\"label-close\" (click)=\"removeLabel(item)\">&times;</i>{{formatter(item)}}</span></li><li *ngIf=\"!disabled\"><input id=\"mutiple-label-auto-complete-{{id}}\" name=\"mutipleAutoComplete\" class=\"auto-complete-control\" [(ngModel)]=\"selectValue\" (selectValueChange)=\"onMutipleSearch()\" [onSearch]=\"onSearch\" [cssClass]=\"popupCssClass\" [delay]=\"delay\" [minLength]=\"minLength\" [itemTemplate]=\"itemTemplate\" [noResultItemTemplate]=\"noResultItemTemplate\" [formatter]=\"formatter\" [valueParser]=\"valueParser\" (keydown.backspace)=\"onMutipleSearchBoxBackspace($event)\" [disabled]=\"disabled\" [dataSource]=\"dataSource\" [appendBody]=\"appendBody\" reAutoComplete></li></ul></label>\n  ",
                styles: ["\n    .mutiple-label-auto-complete{padding:0;font-weight:400}.mutiple-label-auto-complete ul{display:block;list-style:none;width:100%;padding:2px;background-color:#fff;border:1px solid #ccc;border-radius:4px}.mutiple-label-auto-complete ul:focus{border-color:#66afe9;outline:1px}.mutiple-label-auto-complete ul::-ms-expand{border:0;background-color:transparent}.mutiple-label-auto-complete ul li{display:inline-block;margin:5px}.mutiple-label-auto-complete ul li .label-close{cursor:pointer;margin-right:5px;font-weight:700;font-size:1.5rem}.mutiple-label-auto-complete ul .auto-complete-control{height:100%;border:none;outline:0}.mutiple-label-auto-complete ul .auto-complete-control :focus{border:none;outline:0}\n  "],
                providers: [{
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(function () { return MutipleAutoCompleteComponent; }),
                        multi: true
                    }]
            },] },
];
/** @nocollapse */
MutipleAutoCompleteComponent.ctorParameters = function () { return [
    { type: RebirthNGConfig, },
    { type: ChangeDetectorRef, },
]; };
MutipleAutoCompleteComponent.propDecorators = {
    'disabled': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'popupCssClass': [{ type: Input },],
    'delay': [{ type: Input },],
    'minLength': [{ type: Input },],
    'appendBody': [{ type: Input },],
    'dataSource': [{ type: Input },],
    'itemTemplate': [{ type: Input },],
    'noResultItemTemplate': [{ type: Input },],
    'formatter': [{ type: Input },],
    'valueParser': [{ type: Input },],
    'onSearch': [{ type: Input },],
    'autoCompleteDirective': [{ type: ViewChild, args: [AutoCompleteDirective,] },],
};
//# sourceMappingURL=mutiple-auto-complete.component.js.map