import { Injectable, ComponentFactoryResolver } from '@angular/core';
import { ModalService } from '../modal/modal.service';
import { AlertDialogComponent } from './alert-dialog.component';
import { ConfirmDialogComponent } from './confirm-dialog.component';
import { DomSanitizer } from '@angular/platform-browser';
var DialogService = (function () {
    function DialogService(modalService, componentFactoryResolver, domSanitizer) {
        this.modalService = modalService;
        this.componentFactoryResolver = componentFactoryResolver;
        this.domSanitizer = domSanitizer;
    }
    DialogService.prototype.alert = function (dialogOptions) {
        if (dialogOptions.content && dialogOptions.html && (typeof dialogOptions.content === 'string')) {
            dialogOptions.content = this.domSanitizer.bypassSecurityTrustHtml(dialogOptions.content);
        }
        return this.modalService.open({
            component: AlertDialogComponent,
            componentFactoryResolver: this.componentFactoryResolver,
            resolve: dialogOptions,
            modalClass: dialogOptions.cssClass,
            injector: dialogOptions.injector,
            rootContainer: dialogOptions.rootContainer,
            backdrop: dialogOptions.backdrop,
            backdropClass: dialogOptions.backdropClass,
            modal: dialogOptions.modal,
            keyboard: dialogOptions.keyboard,
        });
    };
    DialogService.prototype.confirm = function (dialogOptions) {
        if (dialogOptions.content && dialogOptions.html && (typeof dialogOptions.content === 'string')) {
            dialogOptions.content = this.domSanitizer.bypassSecurityTrustHtml(dialogOptions.content);
        }
        return this.modalService.open({
            component: ConfirmDialogComponent,
            componentFactoryResolver: this.componentFactoryResolver,
            resolve: dialogOptions,
            modalClass: dialogOptions.cssClass,
            injector: dialogOptions.injector,
            rootContainer: dialogOptions.rootContainer,
            backdrop: dialogOptions.backdrop,
            backdropClass: dialogOptions.backdropClass,
            modal: dialogOptions.modal,
            keyboard: dialogOptions.keyboard,
        });
    };
    return DialogService;
}());
export { DialogService };
DialogService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
DialogService.ctorParameters = function () { return [
    { type: ModalService, },
    { type: ComponentFactoryResolver, },
    { type: DomSanitizer, },
]; };
//# sourceMappingURL=dialog.service.js.map