import { Component, Input, ChangeDetectionStrategy, forwardRef, ChangeDetectorRef } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { RebirthNGConfig } from '../rebirth-ng.config';
var SwitchComponent = (function () {
    function SwitchComponent(rebirthNGConfig, changeDetectorRef) {
        this.changeDetectorRef = changeDetectorRef;
        this.onChange = function (_) { return null; };
        this.onTouched = function () { return null; };
        this.onText = rebirthNGConfig.switchBtn.onText;
        this.offText = rebirthNGConfig.switchBtn.offText;
        this.type = rebirthNGConfig.switchBtn.type;
    }
    SwitchComponent.prototype.toggle = function () {
        if (this.disabled) {
            return;
        }
        this.onTouched();
        this.checked = !this.checked;
        this.onChange(this.checked);
    };
    SwitchComponent.prototype.writeValue = function (obj) {
        this.checked = obj;
        this.changeDetectorRef.markForCheck();
    };
    SwitchComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    SwitchComponent.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    SwitchComponent.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
    };
    return SwitchComponent;
}());
export { SwitchComponent };
SwitchComponent.decorators = [
    { type: Component, args: [{
                selector: 're-switch',
                template: "\n    <div class=\"switch {{cssClass}} {{size ? 'btn-' + size : ''}}\" (click)=\"toggle()\" [ngClass]=\"{'disabled': disabled}\"><span class=\"switch-left {{checked ? 'bg-'+ type + ' active' : ''}}\">{{onText}} </span><span class=\"switch-right {{!checked ? 'bg-'+ type + ' active' : ''}}\">{{offText}}</span></div>\n  ",
                styles: ["\n    .switch{display:inline-block;cursor:pointer;-webkit-border-radius:5px;-moz-border-radius:5px;border-radius:5px;border:1px solid #ccc;position:relative;text-align:left;overflow:hidden;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;width:100px;white-space:nowrap;padding:0;text-overflow:ellipsis}.switch .switch-left,.switch .switch-right{box-sizing:border-box;cursor:pointer;position:relative;display:inline-block;width:50%;line-height:2;text-align:center}.switch.disabled .switch-left,.switch.disabled .switch-right{cursor:not-allowed;opacity:.65;filter:alpha(opacity=65);box-shadow:none}.switch.btn-lg{width:120px}.switch.btn-sm{width:100px}.switch.btn-xs{width:80px}\n  "],
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(function () { return SwitchComponent; }),
                        multi: true
                    }]
            },] },
];
/** @nocollapse */
SwitchComponent.ctorParameters = function () { return [
    { type: RebirthNGConfig, },
    { type: ChangeDetectorRef, },
]; };
SwitchComponent.propDecorators = {
    'type': [{ type: Input },],
    'size': [{ type: Input },],
    'disabled': [{ type: Input },],
    'onText': [{ type: Input },],
    'offText': [{ type: Input },],
    'cssClass': [{ type: Input },],
};
//# sourceMappingURL=switch.component.js.map